django-hilbert
===================

This is one of many Django apps which is a loose collection of utility functions.
It is a mixture of Python code and Javascript that I find myself writing over and 
over. Primarily it focuses around utilities for AJAX and testing.


Installation Requirements
-----------------------------------

- `Django <http://www.djangoproject.com/>`_ >= 1.2
- `jQuery <http://jquery.com/>`_ >= 1.4.2

Optional (but recommended)

- `django-staticfiles <https://github.com/jezdez/django-staticfiles>`_

The jQuery library is not included in the distribution but should be included
in your templates.

To use the :ref:`CoverageRunner` you need to install Ned Batchelder's
`coverage.py <http://nedbatchelder.com/code/modules/coverage.html>`_.


Installation Instructions
-----------------------------------

It is easiest to install django-hilbert from `PyPi <http://pypi.python.org/pypi>`_::
    
    pip instal django-hilbert

